import { forwardRef, useEffect, useImperativeHandle, useRef } from 'react';

export default forwardRef(function TextArea({ className = '', isFocused = false, children, ...props }, ref) {
    const localRef = useRef(null);

    useImperativeHandle(ref, () => ({
        focus: () => localRef.current?.focus(),
    }));

    useEffect(() => {
        if (isFocused) {
            localRef.current?.focus();
        }
    }, [isFocused]);

    return (
        <textarea
            {...props}
            className={'rounded-lg py-[8px] border border-border focus:border-border focus:ring-border lg:text-sm sm:text-lg bg-background-secondary w-full ' + className}
            ref={localRef}
        >{children}</textarea>
    );
});
